@@ -107,3 +107,45 @@ function setoddeven() {
   .filter(':odd').addClass('even').end()
   .filter(':even').addClass('odd');
 }
+
+function submitFormHelper(form, onsuccess=submitFormHelperOnsuccessDefault, onerror=null) {
+    $('input#form-buttons-apply').click(function(event) {
+      event.preventDefault();
+      data = $(this.form).serializeArray();
+      // buttons are not included by serializeArray but we need it
+      buttons = $("input[name^='form.buttons']", this.form);
+      buttons.each(function() {data.push({name: this.name, value: this.value});});
+      // include ajax_load meaning we are in an overlay
+      data.push({name: "ajax_load", value: true});
+      $.ajax( {
+      type: 'POST',
+      url: this.form.action,
+      data: data,
+      cache: false,
+      async: false,
+      success: function(data) {
+        if (onsuccess) {return onsuccess(data);}
+      },
+      error: function(jqXHR, textStatus, errorThrown) {
+        if (onerror) {
+          return onerror(data);
+        }
+        else {
+          window.location.href = canonical_url();
+        }
+      },
+    } );
+  });
+}
+
+function submitFormHelperOnsuccessDefault(data) {
+  // close the overlay
+  cancel_button = $('input#form-buttons-cancel');
+  if (cancel_button) {
+    cancel_button.click();
+  }
+  // reload faceted
+  if (has_faceted) {
+    Faceted.URLHandler.hash_changed();
+  }
+}
